const csl = await import("@emurgo/cardano-serialization-lib-nodejs");
const f = await import('@mlabs-haskell/csl-gc-wrapper');
const lib = f.default(csl);

// Explicit re-exports are needed due to how nodejs processes CommonJS imports in ESM.
// If they are dynamic, they are only available via the `default` property of the module.
// Providing them explicitly lets nodejs analyze the module structure and put the
// appropriate entry points to the module interface.

// To re-generate the code below use this snippet:

// for (let key in lib) {
//     if (lib.hasOwnProperty(key)) {
//         module.exports[key] = lib[key];
//         if (!key.startsWith('_'))
//         console.log('export const ' + key + ' = lib["'+key+'"];');
//     }
// }

export const encode_json_str_to_plutus_datum = lib["encode_json_str_to_plutus_datum"];
export const decode_plutus_datum_to_json_str = lib["decode_plutus_datum_to_json_str"];
export const encode_arbitrary_bytes_as_metadatum = lib["encode_arbitrary_bytes_as_metadatum"];
export const decode_arbitrary_bytes_from_metadatum = lib["decode_arbitrary_bytes_from_metadatum"];
export const encode_json_str_to_metadatum = lib["encode_json_str_to_metadatum"];
export const decode_metadatum_to_json_str = lib["decode_metadatum_to_json_str"];
export const min_fee = lib["min_fee"];
export const calculate_ex_units_ceil_cost = lib["calculate_ex_units_ceil_cost"];
export const min_script_fee = lib["min_script_fee"];
export const encrypt_with_password = lib["encrypt_with_password"];
export const decrypt_with_password = lib["decrypt_with_password"];
export const create_send_all = lib["create_send_all"];
export const make_daedalus_bootstrap_witness = lib["make_daedalus_bootstrap_witness"];
export const make_icarus_bootstrap_witness = lib["make_icarus_bootstrap_witness"];
export const make_vkey_witness = lib["make_vkey_witness"];
export const hash_auxiliary_data = lib["hash_auxiliary_data"];
export const hash_transaction = lib["hash_transaction"];
export const hash_plutus_data = lib["hash_plutus_data"];
export const hash_script_data = lib["hash_script_data"];
export const get_implicit_input = lib["get_implicit_input"];
export const get_deposit = lib["get_deposit"];
export const min_ada_for_output = lib["min_ada_for_output"];
export const min_ada_required = lib["min_ada_required"];
export const encode_json_str_to_native_script = lib["encode_json_str_to_native_script"];
export const CertificateKind = lib["CertificateKind"];
export const MIRPot = lib["MIRPot"];
export const MIRKind = lib["MIRKind"];
export const RelayKind = lib["RelayKind"];
export const NativeScriptKind = lib["NativeScriptKind"];
export const ScriptHashNamespace = lib["ScriptHashNamespace"];
export const NetworkIdKind = lib["NetworkIdKind"];
export const LanguageKind = lib["LanguageKind"];
export const PlutusDataKind = lib["PlutusDataKind"];
export const RedeemerTagKind = lib["RedeemerTagKind"];
export const PlutusDatumSchema = lib["PlutusDatumSchema"];
export const TransactionMetadatumKind = lib["TransactionMetadatumKind"];
export const MetadataJsonSchema = lib["MetadataJsonSchema"];
export const CoinSelectionStrategyCIP2 = lib["CoinSelectionStrategyCIP2"];
export const StakeCredKind = lib["StakeCredKind"];
export const ScriptSchema = lib["ScriptSchema"];
export const CborContainerType = lib["CborContainerType"];
export const Address = lib["Address"];
export const AssetName = lib["AssetName"];
export const AssetNames = lib["AssetNames"];
export const Assets = lib["Assets"];
export const AuxiliaryData = lib["AuxiliaryData"];
export const AuxiliaryDataHash = lib["AuxiliaryDataHash"];
export const AuxiliaryDataSet = lib["AuxiliaryDataSet"];
export const BaseAddress = lib["BaseAddress"];
export const BigInt = lib["BigInt"];
export const BigNum = lib["BigNum"];
export const Bip32PrivateKey = lib["Bip32PrivateKey"];
export const Bip32PublicKey = lib["Bip32PublicKey"];
export const Block = lib["Block"];
export const BlockHash = lib["BlockHash"];
export const BootstrapWitness = lib["BootstrapWitness"];
export const BootstrapWitnesses = lib["BootstrapWitnesses"];
export const ByronAddress = lib["ByronAddress"];
export const Certificate = lib["Certificate"];
export const Certificates = lib["Certificates"];
export const ConstrPlutusData = lib["ConstrPlutusData"];
export const CostModel = lib["CostModel"];
export const Costmdls = lib["Costmdls"];
export const DNSRecordAorAAAA = lib["DNSRecordAorAAAA"];
export const DNSRecordSRV = lib["DNSRecordSRV"];
export const DataCost = lib["DataCost"];
export const DataHash = lib["DataHash"];
export const DatumSource = lib["DatumSource"];
export const Ed25519KeyHash = lib["Ed25519KeyHash"];
export const Ed25519KeyHashes = lib["Ed25519KeyHashes"];
export const Ed25519Signature = lib["Ed25519Signature"];
export const EnterpriseAddress = lib["EnterpriseAddress"];
export const ExUnitPrices = lib["ExUnitPrices"];
export const ExUnits = lib["ExUnits"];
export const FixedTransaction = lib["FixedTransaction"];
export const GeneralTransactionMetadata = lib["GeneralTransactionMetadata"];
export const GenesisDelegateHash = lib["GenesisDelegateHash"];
export const GenesisHash = lib["GenesisHash"];
export const GenesisHashes = lib["GenesisHashes"];
export const GenesisKeyDelegation = lib["GenesisKeyDelegation"];
export const Header = lib["Header"];
export const HeaderBody = lib["HeaderBody"];
export const InputWithScriptWitness = lib["InputWithScriptWitness"];
export const InputsWithScriptWitness = lib["InputsWithScriptWitness"];
export const Int = lib["Int"];
export const Ipv4 = lib["Ipv4"];
export const Ipv6 = lib["Ipv6"];
export const KESSignature = lib["KESSignature"];
export const KESVKey = lib["KESVKey"];
export const Language = lib["Language"];
export const Languages = lib["Languages"];
export const LegacyDaedalusPrivateKey = lib["LegacyDaedalusPrivateKey"];
export const LinearFee = lib["LinearFee"];
export const MIRToStakeCredentials = lib["MIRToStakeCredentials"];
export const MetadataList = lib["MetadataList"];
export const MetadataMap = lib["MetadataMap"];
export const Mint = lib["Mint"];
export const MintAssets = lib["MintAssets"];
export const MintBuilder = lib["MintBuilder"];
export const MintWitness = lib["MintWitness"];
export const MintsAssets = lib["MintsAssets"];
export const MoveInstantaneousReward = lib["MoveInstantaneousReward"];
export const MoveInstantaneousRewardsCert = lib["MoveInstantaneousRewardsCert"];
export const MultiAsset = lib["MultiAsset"];
export const MultiHostName = lib["MultiHostName"];
export const NativeScript = lib["NativeScript"];
export const NativeScripts = lib["NativeScripts"];
export const NetworkId = lib["NetworkId"];
export const NetworkInfo = lib["NetworkInfo"];
export const Nonce = lib["Nonce"];
export const OperationalCert = lib["OperationalCert"];
export const PlutusData = lib["PlutusData"];
export const PlutusList = lib["PlutusList"];
export const PlutusMap = lib["PlutusMap"];
export const PlutusScript = lib["PlutusScript"];
export const PlutusScriptSource = lib["PlutusScriptSource"];
export const PlutusScripts = lib["PlutusScripts"];
export const PlutusWitness = lib["PlutusWitness"];
export const PlutusWitnesses = lib["PlutusWitnesses"];
export const Pointer = lib["Pointer"];
export const PointerAddress = lib["PointerAddress"];
export const PoolMetadata = lib["PoolMetadata"];
export const PoolMetadataHash = lib["PoolMetadataHash"];
export const PoolParams = lib["PoolParams"];
export const PoolRegistration = lib["PoolRegistration"];
export const PoolRetirement = lib["PoolRetirement"];
export const PrivateKey = lib["PrivateKey"];
export const ProposedProtocolParameterUpdates = lib["ProposedProtocolParameterUpdates"];
export const ProtocolParamUpdate = lib["ProtocolParamUpdate"];
export const ProtocolVersion = lib["ProtocolVersion"];
export const PublicKey = lib["PublicKey"];
export const PublicKeys = lib["PublicKeys"];
export const Redeemer = lib["Redeemer"];
export const RedeemerTag = lib["RedeemerTag"];
export const Redeemers = lib["Redeemers"];
export const Relay = lib["Relay"];
export const Relays = lib["Relays"];
export const RewardAddress = lib["RewardAddress"];
export const RewardAddresses = lib["RewardAddresses"];
export const ScriptAll = lib["ScriptAll"];
export const ScriptAny = lib["ScriptAny"];
export const ScriptDataHash = lib["ScriptDataHash"];
export const ScriptHash = lib["ScriptHash"];
export const ScriptHashes = lib["ScriptHashes"];
export const ScriptNOfK = lib["ScriptNOfK"];
export const ScriptPubkey = lib["ScriptPubkey"];
export const ScriptRef = lib["ScriptRef"];
export const SingleHostAddr = lib["SingleHostAddr"];
export const SingleHostName = lib["SingleHostName"];
export const StakeCredential = lib["StakeCredential"];
export const StakeCredentials = lib["StakeCredentials"];
export const StakeDelegation = lib["StakeDelegation"];
export const StakeDeregistration = lib["StakeDeregistration"];
export const StakeRegistration = lib["StakeRegistration"];
export const Strings = lib["Strings"];
export const TimelockExpiry = lib["TimelockExpiry"];
export const TimelockStart = lib["TimelockStart"];
export const Transaction = lib["Transaction"];
export const TransactionBatch = lib["TransactionBatch"];
export const TransactionBatchList = lib["TransactionBatchList"];
export const TransactionBodies = lib["TransactionBodies"];
export const TransactionBody = lib["TransactionBody"];
export const TransactionBuilder = lib["TransactionBuilder"];
export const TransactionBuilderConfig = lib["TransactionBuilderConfig"];
export const TransactionBuilderConfigBuilder = lib["TransactionBuilderConfigBuilder"];
export const TransactionHash = lib["TransactionHash"];
export const TransactionInput = lib["TransactionInput"];
export const TransactionInputs = lib["TransactionInputs"];
export const TransactionMetadatum = lib["TransactionMetadatum"];
export const TransactionMetadatumLabels = lib["TransactionMetadatumLabels"];
export const TransactionOutput = lib["TransactionOutput"];
export const TransactionOutputAmountBuilder = lib["TransactionOutputAmountBuilder"];
export const TransactionOutputBuilder = lib["TransactionOutputBuilder"];
export const TransactionOutputs = lib["TransactionOutputs"];
export const TransactionUnspentOutput = lib["TransactionUnspentOutput"];
export const TransactionUnspentOutputs = lib["TransactionUnspentOutputs"];
export const TransactionWitnessSet = lib["TransactionWitnessSet"];
export const TransactionWitnessSets = lib["TransactionWitnessSets"];
export const TxBuilderConstants = lib["TxBuilderConstants"];
export const TxInputsBuilder = lib["TxInputsBuilder"];
export const URL = lib["URL"];
export const UnitInterval = lib["UnitInterval"];
export const Update = lib["Update"];
export const VRFCert = lib["VRFCert"];
export const VRFKeyHash = lib["VRFKeyHash"];
export const VRFVKey = lib["VRFVKey"];
export const Value = lib["Value"];
export const Vkey = lib["Vkey"];
export const Vkeys = lib["Vkeys"];
export const Vkeywitness = lib["Vkeywitness"];
export const Vkeywitnesses = lib["Vkeywitnesses"];
export const Withdrawals = lib["Withdrawals"];
